@@ -10,7 +10,7 @@ use Carp qw(croak carp);
 #######################
 # VERSION
 #######################
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.1';
 
 #######################
 # LOAD CPAN MODULES
@@ -22,6 +22,7 @@ use Object::Tiny qw(session);
 #######################
 use TMDB::Genre;
 use TMDB::Movie;
+use TMDB::TV;
 use TMDB::Config;
 use TMDB::Person;
 use TMDB::Search;
@@ -59,6 +60,7 @@ sub company { return TMDB::Company->new( session => shift->session, @_ ); }
 sub config { return TMDB::Config->new( session => shift->session, @_ ); }
 sub genre { return TMDB::Genre->new( session => shift->session, @_ ); }
 sub movie { return TMDB::Movie->new( session => shift->session, @_ ); }
+sub tv { return TMDB::TV->new( session => shift->session, @_ ); }
 sub person { return TMDB::Person->new( session => shift->session, @_ ); }
 sub search { return TMDB::Search->new( session => shift->session, @_ ); }
 
@@ -190,8 +192,8 @@ is used.
 =item json
 
 You can provide your own L<JSON> implementation that can C<decode>
-JSON. This will fall back to using L<JSON::Any>. However, L<JSON::XS>
-is recommended.
+JSON. This will fall back to using L<JSON::MaybeXS>. However,
+L<JSON::XS> is recommended.
 
 =item apiurl
 
@@ -390,7 +392,7 @@ L<http://docs.themoviedb.apiary.io/#configuration> for more details.
 
 =item L<HTTP::Tiny>
 
-=item L<JSON::Any>
+=item L<JSON::MaybeXS>
 
 =item L<Locale::Codes>
 
